use serde::{Deserialize, Serialize};

use super::{ElementContent, ElementId, MessageId, PotId};

#[derive(Serialize, Deserialize, Clone, Debug, PartialEq)]
pub struct Element {
    // Uuid identifying the element itself
    id: ElementId,
    pot: Option<PotId>,
    content: ElementContent,
    latest_message: Option<MessageId>,
    local_changes: bool,
}


impl From<(ElementId, Option<PotId>, ElementContent, Option<MessageId>, bool)> for Element {
    fn from(value: (ElementId, Option<PotId>, ElementContent, Option<MessageId>, bool)) -> Self {
        Element {
            id: value.0,
            pot: value.1,
            content: value.2,
            latest_message: value.3,
            local_changes: value.4,
        }
    }
}

impl Element {
    pub fn new(id: ElementId, content: ElementContent) -> Self {
        // A new element with no latest message must have local changes
        Element {
            id: id,
            pot: None,
            content: content,
            latest_message: None,
            local_changes: true,
        }
    }

    pub fn id(&self) -> &ElementId {
        &self.id
    }
    pub fn content(&self) -> &ElementContent {
        &self.content
    }
    pub fn pot(&self) -> &Option<PotId> {
        &self.pot
    }
    pub fn latest_message(&self) -> &Option<MessageId> {
        &self.latest_message
    }
    pub fn local_changes(&self) -> bool {
        self.local_changes
    }
}
